@@ -1,7 +1,7 @@
 ### R code from vignette source 'recommenderlab.Rnw'
 
 ###################################################
-### code chunk number 1: recommenderlab.Rnw:101-104
+### code chunk number 1: recommenderlab.Rnw:88-91
 ###################################################
 options(scipen=3, digits=4, prompt="R> ", eps=FALSE, width=75)
 ### for sampling
@@ -9,19 +9,13 @@ set.seed(1234)
 
 
 ###################################################
-### code chunk number 2: recommenderlab.Rnw:238-239
-###################################################
-citation("recommenderlab")
-
-
-###################################################
-### code chunk number 3: recommenderlab.Rnw:1077-1078
+### code chunk number 2: recommenderlab.Rnw:1088-1089
 ###################################################
 library("recommenderlab")
 
 
 ###################################################
-### code chunk number 4: recommenderlab.Rnw:1086-1091
+### code chunk number 3: recommenderlab.Rnw:1097-1102
 ###################################################
 m <- matrix(sample(c(as.numeric(0:5), NA), 50,
     replace=TRUE, prob=c(rep(.4/6,6),.6)), ncol=10,
@@ -31,7 +25,7 @@ m
 
 
 ###################################################
-### code chunk number 5: recommenderlab.Rnw:1099-1102
+### code chunk number 4: recommenderlab.Rnw:1110-1113
 ###################################################
 r <- as(m, "realRatingMatrix")
 r
@@ -39,20 +33,20 @@ getRatingMatrix(r)
 
 
 ###################################################
-### code chunk number 6: recommenderlab.Rnw:1107-1108
+### code chunk number 5: recommenderlab.Rnw:1118-1119
 ###################################################
 identical(as(r, "matrix"),m)
 
 
 ###################################################
-### code chunk number 7: recommenderlab.Rnw:1115-1117
+### code chunk number 6: recommenderlab.Rnw:1126-1128
 ###################################################
 as(r, "list")
 head(as(r, "data.frame"))
 
 
 ###################################################
-### code chunk number 8: recommenderlab.Rnw:1132-1135
+### code chunk number 7: recommenderlab.Rnw:1143-1146
 ###################################################
 r_m <- normalize(r)
 r_m
@@ -60,32 +54,32 @@ getRatingMatrix(r_m)
 
 
 ###################################################
-### code chunk number 9: recommenderlab.Rnw:1139-1140
+### code chunk number 8: recommenderlab.Rnw:1150-1151
 ###################################################
 denormalize(r_m)
 
 
 ###################################################
-### code chunk number 10: recommenderlab.Rnw:1146-1148 (eval = FALSE)
+### code chunk number 9: recommenderlab.Rnw:1157-1159 (eval = FALSE)
 ###################################################
 ## image(r, main = "Raw Ratings")
 ## image(r_m, main = "Normalized Ratings")
 
 
 ###################################################
-### code chunk number 11: image1
+### code chunk number 10: image1
 ###################################################
 print(image(r, main = "Raw Ratings"))
 
 
 ###################################################
-### code chunk number 12: image2
+### code chunk number 11: image2
 ###################################################
 print(image(r_m, main = "Normalized Ratings"))
 
 
 ###################################################
-### code chunk number 13: recommenderlab.Rnw:1181-1184
+### code chunk number 12: recommenderlab.Rnw:1192-1195
 ###################################################
 r_b <- binarize(r, minRating=4)
 r_b
@@ -93,14 +87,14 @@ as(r_b, "matrix")
 
 
 ###################################################
-### code chunk number 14: recommenderlab.Rnw:1196-1198
+### code chunk number 13: recommenderlab.Rnw:1207-1209
 ###################################################
 data(Jester5k)
 Jester5k
 
 
 ###################################################
-### code chunk number 15: recommenderlab.Rnw:1207-1210
+### code chunk number 14: recommenderlab.Rnw:1218-1221
 ###################################################
 set.seed(1234)
 r <- sample(Jester5k, 1000)
@@ -108,7 +102,7 @@ r
 
 
 ###################################################
-### code chunk number 16: recommenderlab.Rnw:1217-1220
+### code chunk number 15: recommenderlab.Rnw:1228-1231
 ###################################################
 rowCounts(r[1,])
 as(r[1,], "list")
@@ -116,70 +110,70 @@ rowMeans(r[1,])
 
 
 ###################################################
-### code chunk number 17: hist1
+### code chunk number 16: hist1
 ###################################################
 hist(getRatings(r), breaks=100)
 
 
 ###################################################
-### code chunk number 18: hist2
+### code chunk number 17: hist2
 ###################################################
 hist(getRatings(normalize(r)), breaks=100)
 
 
 ###################################################
-### code chunk number 19: hist3
+### code chunk number 18: hist3
 ###################################################
 hist(getRatings(normalize(r, method="Z-score")), breaks=100)
 
 
 ###################################################
-### code chunk number 20: hist4
+### code chunk number 19: hist4
 ###################################################
 hist(rowCounts(r), breaks=50)
 
 
 ###################################################
-### code chunk number 21: hist5
+### code chunk number 20: hist5
 ###################################################
 hist(colMeans(r), breaks=20)
 
 
 ###################################################
-### code chunk number 22: recommenderlab.Rnw:1309-1310
+### code chunk number 21: recommenderlab.Rnw:1320-1321
 ###################################################
 recommenderRegistry$get_entries(dataType = "realRatingMatrix")
 
 
 ###################################################
-### code chunk number 23: recommenderlab.Rnw:1318-1320
+### code chunk number 22: recommenderlab.Rnw:1329-1331
 ###################################################
 r <- Recommender(Jester5k[1:1000], method = "POPULAR")
 r
 
 
 ###################################################
-### code chunk number 24: recommenderlab.Rnw:1324-1326
+### code chunk number 23: recommenderlab.Rnw:1335-1337
 ###################################################
 names(getModel(r))
 getModel(r)$topN
 
 
 ###################################################
-### code chunk number 25: recommenderlab.Rnw:1341-1343
+### code chunk number 24: recommenderlab.Rnw:1352-1354
 ###################################################
 recom <- predict(r, Jester5k[1001:1002], n=5)
 recom
 
 
 ###################################################
-### code chunk number 26: recommenderlab.Rnw:1348-1349
+### code chunk number 25: recommenderlab.Rnw:1359-1360
 ###################################################
 as(recom, "list")
 
 
 ###################################################
-### code chunk number 27: recommenderlab.Rnw:1355-1358
+### code chunk number 26: recommenderlab.Rnw:1366-1369
 ###################################################
 recom3 <- bestN(recom, n = 3)
 recom3
@@ -187,7 +181,7 @@ as(recom3, "list")
 
 
 ###################################################
-### code chunk number 28: recommenderlab.Rnw:1366-1369
+### code chunk number 27: recommenderlab.Rnw:1377-1380
 ###################################################
 recom <- predict(r, Jester5k[1001:1002], type="ratings")
 recom
@@ -195,7 +189,7 @@ as(recom, "matrix")[,1:10]
 
 
 ###################################################
-### code chunk number 29: recommenderlab.Rnw:1380-1383
+### code chunk number 28: recommenderlab.Rnw:1391-1394
 ###################################################
 recom <- predict(r, Jester5k[1001:1002], type="ratingMatrix")
 recom
@@ -203,7 +197,7 @@ as(recom, "matrix")[,1:10]
 
 
 ###################################################
-### code chunk number 30: recommenderlab.Rnw:1398-1401
+### code chunk number 29: recommenderlab.Rnw:1409-1412
 ###################################################
 e <- evaluationScheme(Jester5k[1:1000], method="split", train=0.9,
     given=15, goodRating=5)
@@ -211,7 +205,7 @@ e
 
 
 ###################################################
-### code chunk number 31: recommenderlab.Rnw:1407-1412
+### code chunk number 30: recommenderlab.Rnw:1418-1423
 ###################################################
 r1 <- Recommender(getData(e, "train"), "UBCF")
 r1
@@ -221,7 +215,7 @@ r2
 
 
 ###################################################
-### code chunk number 32: recommenderlab.Rnw:1419-1423
+### code chunk number 31: recommenderlab.Rnw:1430-1434
 ###################################################
 p1 <- predict(r1, getData(e, "known"), type="ratings")
 p1
@@ -230,7 +224,7 @@ p2
 
 
 ###################################################
-### code chunk number 33: recommenderlab.Rnw:1429-1434
+### code chunk number 32: recommenderlab.Rnw:1440-1445
 ###################################################
 error <- rbind(
   UBCF = calcPredictionAccuracy(p1, getData(e, "unknown")),
@@ -240,7 +234,7 @@ error
 
 
 ###################################################
-### code chunk number 34: recommenderlab.Rnw:1447-1450
+### code chunk number 33: recommenderlab.Rnw:1458-1461
 ###################################################
 scheme <- evaluationScheme(Jester5k[1:1000], method="cross", k=4, given=3,
     goodRating=5)
@@ -248,7 +242,7 @@ scheme
 
 
 ###################################################
-### code chunk number 35: recommenderlab.Rnw:1457-1460
+### code chunk number 34: recommenderlab.Rnw:1468-1471
 ###################################################
 results <- evaluate(scheme, method="POPULAR", type = "topNList",
   n=c(1,3,5,10,15,20))
@@ -256,35 +250,35 @@ results
 
 
 ###################################################
-### code chunk number 36: recommenderlab.Rnw:1471-1472
+### code chunk number 35: recommenderlab.Rnw:1482-1483
 ###################################################
 getConfusionMatrix(results)[[1]]
 
 
 ###################################################
-### code chunk number 37: recommenderlab.Rnw:1484-1485
+### code chunk number 36: recommenderlab.Rnw:1495-1496
 ###################################################
 avg(results)
 
 
 ###################################################
-### code chunk number 38: roc1
+### code chunk number 37: roc1
 ###################################################
 plot(results, annotate=TRUE)
 
 
 ###################################################
-### code chunk number 39: precrec1
+### code chunk number 38: precrec1
 ###################################################
 plot(results, "prec/rec", annotate=TRUE)
 
 
 ###################################################
-### code chunk number 40: recommenderlab.Rnw:1532-1548
+### code chunk number 39: recommenderlab.Rnw:1543-1559
 ###################################################
 set.seed(2016)
 scheme <- evaluationScheme(Jester5k[1:1000], method="split", train = .9,
-  k=1, given=-5, goodRating=5)
+  given=-5, goodRating=5)
 scheme
 
 algorithms <- list(
@@ -301,51 +295,51 @@ results <- evaluate(scheme, algorithms, type = "topNList",
 
 
 ###################################################
-### code chunk number 41: recommenderlab.Rnw:1553-1554
+### code chunk number 40: recommenderlab.Rnw:1564-1565
 ###################################################
 results
 
 
 ###################################################
-### code chunk number 42: recommenderlab.Rnw:1560-1562
+### code chunk number 41: recommenderlab.Rnw:1571-1573
 ###################################################
 names(results)
 results[["user-based CF"]]
 
 
 ###################################################
-### code chunk number 43: roc2
+### code chunk number 42: roc2
 ###################################################
 plot(results, annotate=c(1,3), legend="bottomright")
 
 
 ###################################################
-### code chunk number 44: precrec2
+### code chunk number 43: precrec2
 ###################################################
 plot(results, "prec/rec", annotate=3, legend="topleft")
 
 
 ###################################################
-### code chunk number 45: recommenderlab.Rnw:1605-1607
+### code chunk number 44: recommenderlab.Rnw:1615-1617
 ###################################################
 ## run algorithms
 results <- evaluate(scheme, algorithms, type = "ratings")
 
 
 ###################################################
-### code chunk number 46: recommenderlab.Rnw:1612-1613
+### code chunk number 45: recommenderlab.Rnw:1622-1623
 ###################################################
 results
 
 
 ###################################################
-### code chunk number 47: real
+### code chunk number 46: real
 ###################################################
 plot(results, ylim = c(0,100))
 
 
 ###################################################
-### code chunk number 48: recommenderlab.Rnw:1635-1641
+### code chunk number 47: recommenderlab.Rnw:1645-1651
 ###################################################
 Jester_binary <- binarize(Jester5k, minRating=5)
 Jester_binary <- Jester_binary[rowCounts(Jester_binary)>20]
@@ -356,14 +350,14 @@ scheme_binary
 
 
 ###################################################
-### code chunk number 49: recommenderlab.Rnw:1644-1646
+### code chunk number 48: recommenderlab.Rnw:1654-1656
 ###################################################
 results_binary <- evaluate(scheme_binary, algorithms,
   type = "topNList", n=c(1,3,5,10,15,20))
 
 
 ###################################################
-### code chunk number 50: roc3
+### code chunk number 49: roc3
 ###################################################
 plot(results_binary, annotate=c(1,3), legend="topright")
 
